@@ -1,17 +1,16 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::AuthorityFromModule;
-# git description: v0.003-2-g64a4014
-$Dist::Zilla::Plugin::AuthorityFromModule::VERSION = '0.004';
+package Dist::Zilla::Plugin::AuthorityFromModule; # git description: v0.004-12-ga2ab1f6
 # ABSTRACT: Add metadata to your distribution indicating what module to copy PAUSE permissions from
 # KEYWORDS: distribution metadata authority permissions PAUSE users
-# vim: set ts=8 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
+
+our $VERSION = '0.005';
 
 use Moose;
-with 'Dist::Zilla::Role::MetaProvider';
-use Moose::Util::TypeConstraints 'role_type';
+with 'Dist::Zilla::Role::MetaProvider',
+    'Dist::Zilla::Role::ModuleMetadata';
 use List::Util 1.33 qw(first any);
-use Module::Metadata 1.000005;
 use namespace::autoclean;
 
 has module => (
@@ -31,18 +30,18 @@ has _module_name => (
                     and any { $module eq $_ } $self->_packages_from_file($_) }
                 @{ $self->zilla->files })
             {
-                $self->log_debug('found \'' . $module . '\' in ' . $file->name);
+                $self->log_debug([ 'found \'%s\' in %s', $module, $file->name ]);
                 return $module;
             }
 
-            $self->log_fatal('the module \'' . $module . '\' cannot be found in the distribution');
+            $self->log_fatal([ 'the module \'%s\' cannot be found in the distribution', $module ]);
         }
 
         $self->log_debug('no module provided; defaulting to the main module');
 
         my $file = $self->zilla->main_module;
         my ($module) = $self->_packages_from_file($file);
-        $self->log_debug('extracted package \'' . $module . '\' from ' . $file->name);
+        $self->log_debug([ 'extracted package \'%s\' from %s', $module, $file->name ]);
         $module;
     },
 );
@@ -76,14 +75,7 @@ sub _packages_from_file
 {
     my ($self, $file) = @_;
 
-    # TODO: use Dist::Zilla::Role::ModuleMetadata
-    my $fh;
-    ($file->can('encoding')
-        ? open $fh, sprintf('<:encoding(%s)', $file->encoding), \$file->encoded_content
-        : open $fh, '<', \$file->content)
-            or $self->log_fatal('cannot open handle to ' . $file->name . ' content: ' . $!);
-
-    my $mmd = Module::Metadata->new_from_handle($fh, $file->name);
+    my $mmd = $self->module_metadata_for_file($file);
     grep { $_ ne 'main' } $mmd->packages_inside;
 }
 
@@ -101,7 +93,7 @@ Dist::Zilla::Plugin::AuthorityFromModule - Add metadata to your distribution ind
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
